Documentation
¶
Overview ¶
Package k8s provides a configuration reader implementation for Kubernetes ConfigMaps and Secrets. It supports reading configuration data from Kubernetes resources and subscribing to changes.
Index ¶
Constants ¶
const ( // SchemeK8S represents kubernetes URI scheme SchemeK8S reader.Scheme = "k8s" // ResourceTypeConfigMap represents configmap resource type ResourceTypeConfigMap = "configmap" // ResourceTypeSecret represents secret resource type ResourceTypeSecret = "secret" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type K8SReader ¶
type K8SReader struct {
// contains filtered or unexported fields
}
K8SReader implements ConfReader for kubernetes configmap/secret
func NewK8SReader ¶
NewK8SReader creates a new k8s reader URI format: k8s://{resourceType}/{namespace}/{name}[/{key}] Example: k8s://configmap/default/my-config/config.yaml
Click to show internal directories.
Click to hide internal directories.